// USB Camera PCB Mount
// Ed Nisley KE4ZNU - August 2013

Layout = "Camera";                    // Show Build Camera

//-------
//- Extrusion parameters must match reality!
//  Print with 2 shells

ThreadThick = 0.25;
ThreadWidth = 0.40;

HoleFinagle = 0.2;
HoleFudge = 1.00;

function HoleAdjust(Diameter) = HoleFudge*Diameter + HoleFinagle;

Protrusion = 0.1;           // make holes end cleanly

function IntegerMultiple(Size,Unit) = Unit * ceil(Size / Unit);
function IntegerMultipleMin(Size,Unit) = Unit * floor(Size / Unit);

//-------
// Dimensions

//-- Camera

PCBThick = 1.1;
PCBDia = 24.0;
KeySize = [27.0,9.0,PCBThick];
KeyOffset = [0.0,3.0,0];

PartsBottomHeight = 6.0;
PartsBottomDia = PCBDia - 1.0;

PartsTopHeight = 5.0;
PartsTopDia = PCBDia - 0.5;

LensMountDia = 14.0;
LensMountHeight = 18.0 + PCBThick;	// lens full extension

LensKnobOD = 18.0;					// octagonal point-to-point
LensKnobThick = 4.0;				//

CameraHeight = PCBThick + PartsBottomHeight + LensMountHeight + LensKnobThick;
echo(str("Camera Height:",CameraHeight));

PCBTrim = [KeySize[0],2*11.5,3*CameraHeight];

//-------

module PolyCyl(Dia,Height,ForceSides=0) {           // based on nophead's polyholes
  Sides = (ForceSides != 0) ? ForceSides : (ceil(Dia) + 2);
  FixDia = Dia / cos(180/Sides);
  cylinder(r=HoleAdjust(FixDia)/2,h=Height,$fn=Sides);
}

module ShowPegGrid(Space = 10.0,Size = 1.0) {

  RangeX = floor(100 / Space);
  RangeY = floor(125 / Space);

	for (x=[-RangeX:RangeX])
	  for (y=[-RangeY:RangeY])
		translate([x*Space,y*Space,Size/2])
		  %cube(Size,center=true);

}

//-------
// Components

//--
// Camera outline

module CameraShape() {
$fn = 8*4;

	intersection() {
		union() {
			color("DarkGreen")
			cylinder(r=PCBDia/2,h=PCBThick);
			
			color("DarkGreen")
			translate([KeyOffset[0],KeyOffset[1],PCBThick/2])
				cube(KeySize,center=true);
			
			color("Orange")
			translate([0,0,-PartsBottomHeight])
				cylinder(r=PartsBottomDia/2,h=(PartsBottomHeight + Protrusion));
			
			color("DarkOrange")
			translate([0,0,(PCBThick - Protrusion)])
				cylinder(r=PartsTopDia/2,h=(PartsTopHeight + Protrusion));
			
			color("Yellow")
			cylinder(r=LensMountDia/2,h=(LensMountHeight + Protrusion));
			
			color("Gold")
			translate([0,0,LensMountHeight])
				cylinder(r=LensKnobOD/2,h=LensKnobThick);
		}
		cube(PCBTrim,center=true);
	}
}

//-------
// Build it!

ShowPegGrid();

	
if (Layout == "Camera")
		CameraShape();
	
	
if (Layout == "Build")
	minkowski() {
		CameraShape();
		sphere(r=0.1,$fn=8);
	}
	
	